commit a0541fdbeb08247b8c97f2f01e922452ffb4bc9e
Author: Erik Zeek <zeekec@gmail.com>
Date:   Mon Jul 21 20:21:07 2025 -0600

    Use boost/process/v1 for newer boosts
    
    Signed-off-by: Erik Zeek <zeekec@gmail.com>

diff --git a/LspCpp/examples/StdIOClientExample.cpp b/LspCpp/examples/StdIOClientExample.cpp
index 13bf9da..48a9ace 100644
--- a/LspCpp/examples/StdIOClientExample.cpp
+++ b/LspCpp/examples/StdIOClientExample.cpp
@@ -17,7 +17,17 @@
 #include "LibLsp/JsonRpc/TcpServer.h"
 #include "LibLsp/lsp/textDocument/document_symbol.h"
 #include "LibLsp/lsp/workspace/execute_command.h"
+
+#include <boost/version.hpp>
+#if BOOST_VERSION >= 108800 // v2 is now default
+#define BOOST_PROCESS_VERSION 1
+#include <boost/process/v1/child.hpp>
+#include <boost/process/v1/io.hpp>
+#include <boost/process/v1/pipe.hpp>
+#else
 #include <boost/process.hpp>
+#endif
+
 #include <boost/filesystem.hpp>
 #include <boost/asio.hpp>
 #include <iostream>
diff --git a/LspCpp/examples/StdIOServerExample.cpp b/LspCpp/examples/StdIOServerExample.cpp
index 8b2d2b2..f38e4a7 100644
--- a/LspCpp/examples/StdIOServerExample.cpp
+++ b/LspCpp/examples/StdIOServerExample.cpp
@@ -16,7 +16,17 @@
 #include "LibLsp/JsonRpc/TcpServer.h"
 #include "LibLsp/lsp/textDocument/document_symbol.h"
 #include "LibLsp/lsp/workspace/execute_command.h"
+
+#include <boost/version.hpp>
+#if BOOST_VERSION >= 108800 // v2 is now default
+#define BOOST_PROCESS_VERSION 1
+#include <boost/process/v1/child.hpp>
+#include <boost/process/v1/io.hpp>
+#include <boost/process/v1/pipe.hpp>
+#else
 #include <boost/process.hpp>
+#endif
+
 #include <boost/filesystem.hpp>
 #include <boost/asio.hpp>
 #include <iostream>
diff --git a/LspCpp/src/lsp/ParentProcessWatcher.cpp b/LspCpp/src/lsp/ParentProcessWatcher.cpp
index ee4147b..8ecc05d 100644
--- a/LspCpp/src/lsp/ParentProcessWatcher.cpp
+++ b/LspCpp/src/lsp/ParentProcessWatcher.cpp
@@ -1,6 +1,17 @@
 #include "LibLsp/lsp/ParentProcessWatcher.h"
 #include <algorithm>
+
+#include <boost/version.hpp>
+#if BOOST_VERSION >= 108800 // v2 is now default
+#define BOOST_PROCESS_VERSION 1
+#include <boost/process/v1/child.hpp>
+#include <boost/process/v1/io.hpp>
+#include <boost/process/v1/pipe.hpp>
+#include <boost/process/v1/system.hpp>
+#else
 #include <boost/process.hpp>
+#error "V1"
+#endif
 
 #ifdef _WIN32
 #include <boost/process/v1/windows.hpp>
